Index: remoting/host/chromoting_host.h |
diff --git a/remoting/host/chromoting_host.h b/remoting/host/chromoting_host.h |
index 2294fdd701862c18b814e947c2764fb4e8299769..cac44bb967dcf10d530a9b43d28f91f1b5604ba7 100644 |
--- a/remoting/host/chromoting_host.h |
+++ b/remoting/host/chromoting_host.h |
@@ -32,7 +32,7 @@ class Capturer; |
class ChromotingHostContext; |
class Encoder; |
class MutableHostConfig; |
-class SessionManager; |
+class ScreenRecorder; |
// A class to implement the functionality of a host process. |
// |
@@ -44,17 +44,17 @@ class SessionManager; |
// |
// 2. We listen for incoming connection using libjingle. We will create |
// a ConnectionToClient object that wraps around linjingle for transport. |
-// Also create a SessionManager with appropriate Encoder and Capturer and |
-// add the ConnectionToClient to this SessionManager for transporting the |
-// screen captures. An InputStub is created and registered with the |
+// A ScreenRecorder is created with Encoder and Capturer. |
dmac
2010/11/19 23:24:24
with an Encoder and a Capturer.
|
+// ConnectionToClient is added to this SCreenRecorder for transporting |
dmac
2010/11/19 23:24:24
A ConnectionToClient is added to the ScreenRecorde
|
+// the screen captures. An InputStub is created and registered with the |
// ConnectionToClient to receive mouse / keyboard events from the remote |
// client. |
// This is also the right time to create multiple threads to host |
// the above objects. After we have done all the initialization |
// we'll start the SessionManager. We'll then enter the running state |
// of the host process. |
// |
-// 3. When the user is disconencted, we will pause the SessionManager |
+// 3. When the user is disconnected, we will pause the ScreenRecorder |
// and try to terminate the threads we have created. This will allow |
// all pending tasks to complete. After all of that completed we |
// return to the idle state. We then go to step (2) if there a new |
@@ -125,13 +125,10 @@ class ChromotingHost : public base::RefCountedThreadSafe<ChromotingHost>, |
scoped_refptr<MutableHostConfig> config_; |
- // Capturer to be used by SessionManager. Once the SessionManager is |
+ // Capturer to be used by ScreenRecorder. Once the ScreenRecorder is |
// constructed this is set to NULL. |
scoped_ptr<Capturer> capturer_; |
- // constructed this is set to NULL. |
- scoped_ptr<Encoder> encoder_; |
- |
// InputStub in the host executes input events received from the client. |
scoped_ptr<protocol::InputStub> input_stub_; |
@@ -154,7 +151,7 @@ class ChromotingHost : public base::RefCountedThreadSafe<ChromotingHost>, |
scoped_refptr<protocol::ConnectionToClient> connection_; |
// Session manager for the host process. |
- scoped_refptr<SessionManager> session_; |
+ scoped_refptr<ScreenRecorder> recorder_; |
// This task gets executed when this object fails to connect to the |
// talk network or Shutdown() is called. |
@@ -44,17 +44,17 @@ class SessionManager; |
// This is also the right time to create multiple threads to host |
// the above objects. After we have done all the initialization |
-// we'll start the SessionManager. We'll then enter the running state |
+// we'll start the ScreenRecorder. We'll then enter the running state |
// of the host process. |
// |